#
# spec file for package imagewriter
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%if 0%{?rhel_version} == 600
     %define dist el6
     %define breq qt-devel
     %define backend hal-devel
     %define qmake /usr/bin/qmake-qt4
     %define lrelease /usr/bin/lrelease-qt4
     %define definedbackend USEHAL
%endif

%if 0%{?fedora}
    %define breq qt4-devel
    %define backend udisks2
    %define qmake /usr/bin/qmake-qt4
    %define lrelease /usr/bin/lrelease-qt4
    %define definedbackend USEUDISKS2
%endif

%if 0%{?mandriva_version}
    %define breq libqt4-devel
    %define backend hal-devel
    %define qmake /usr/lib/qt4/bin/qmake
    %define lrelease /usr/lib/qt4/bin/lrelease
    %define definedbackend USEHAL
%endif

%if 0%{?suse_version}
    %define breq pkgconfig(Qt5DBus) pkgconfig(Qt5Gui) pkgconfig(Qt5Widgets) update-desktop-files
    %define qmake /usr/bin/qmake-qt5
    %define lrelease /usr/bin/lrelease-qt5
%endif

%if 0%{?suse_version} <= 1130
    %define backend hal-devel
    %define definedbackend USEHAL
%endif

%if 0%{?suse_version} == 1140 || 0%{?suse_version} == 1210
    %define backend udisks
    %define definedbackend USEUDISKS
%endif

%if 0%{?suse_version} >= 1220
    %define backend udisks2
    %define definedbackend USEUDISKS2
%endif

Name:           imagewriter
Version:        1.10.1432200249.1d253d9
Release:        2.15
Summary:        Utility for writing disk images to USB keys
License:        GPL-2.0-only
Group:          Hardware/Other
URL:            https://github.com/openSUSE/imagewriter
Source0:        imagewriter-%{version}.tar.xz
Patch0:         0001-remove-include-sys-sysctl.h.patch
BuildRequires:  %{backend}
BuildRequires:  %{breq}
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  xz
Requires:       xdg-utils

%description
A graphical utility for writing raw disk images & hybrid ISOs to USB keys.

%prep
%autosetup -p1

%build
# Create qmake cache file for building and use optflags.
cat > .qmake.cache <<EOF
PREFIX=%{_prefix}
QMAKE_CXXFLAGS_RELEASE += "%{optflags} -DKIOSKHACK"
DEFINES=%{definedbackend}
EOF
%qmake
make %{?_smp_mflags}

%install
make %{?_smp_mflags} INSTALL_ROOT=%{buildroot} install
%if 0%{?suse_version}
    %suse_update_desktop_file imagewriter
%endif

%if 0%{?suse_version} >= 1140
%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files
%defattr(-,root,root)
%doc COPYING
%{_bindir}/imagewriter
%{_datadir}/applications/imagewriter.desktop
%{_datadir}/icons/hicolor/*/apps/imagewriter.*
%if 0%{?mandriva_version}
%{_mandir}/man1/imagewriter.1.*
%else
%{_mandir}/man1/imagewriter.1%{?ext_man}
%endif

%changelog
* Mon Nov  9 2020 Hans-Peter Jansen <hpj@urpla.net>
- Apply 0001-remove-include-sys-sysctl.h.patch
* Thu May  3 2018 fisiu@opensuse.org
- Update to 1d253d9.
- Build with Qt5.
* Fri Jan  9 2015 jmassaguerpla@suse.com
- Update to latest git release 134a9b3:
  + fix bnc#871120: doesn't unmount partition
  + fix bnc#882153 - disk imagewriter does not work with img
* Tue Dec  9 2014 malcolmlewis@opensuse.org
- Update to latest git release 7998f7c:
  + Man page added.
  + Desktop file fixes to remove path to exec.
  + Update to FSF address in COPYING.
  + Cleanup of build process in cmake project file and rpm spec
    file.
* Mon May 19 2014 jmassaguerpla@suse.de
- add xz as build requirement since the source is in a xz file
* Mon Apr 14 2014 lnussel@suse.de
- run as non-root and use udisks to get the file descriptor for the
  usb device
- generate from git via _service file
* Fri Dec 20 2013 mailaender@opensuse.org
- Add missing .desktop and icon cache update macros
* Wed Nov 14 2012 mbarringer@suse.com
- Updating to 1.10, which adds support for udisks2
* Sat Jul 14 2012 badshah400@gmail.com
- Add imagewriter-desktop-menu-exec.patch to fix imagewriter not
  starting up from the desktop menus, because it requires root
  privilege.
* Fri Mar 16 2012 dimstar@opensuse.org
- Add imagewriter-gcc47.patch: Fix build with gcc 4.7.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed Apr  6 2011 mbarringer@novell.com
- Fixing bnc#679099 - Imagewriter still requires HAL
  - When /usr/include/hal/* is present, HAL will be used.
    Otherwise, UDisks via DBUS will be used.
* Sun Mar 21 2010 mbarringer@novell.com
- Fixing bug 589463 - Imagewriter should display information in the USB dropdown
  - Dropdown now tells the user to insert a device, rather than
    show an empty menu.
* Tue Mar  9 2010 mbarringer@suse.de
- Adding "list" and "kiosk" modes to the command line flags
  - "List" lists valid USB devices
  - "kiosk" mode ignores all USB drives > 200GB
* Fri Feb 26 2010 aj@suse.de
- Use Hardware/Other as group.
* Sat Feb 20 2010 mbarringer@suse.de
- Fixing a bug with non-hybrid ISOs
